<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Http\Requests\Auth\LoginRequest;
use App\Models\Superadmin;
use App\Models\Admin;
use Illuminate\Http\Request;
use Illuminate\Http\JsonResponse;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Log;
use Illuminate\Validation\ValidationException;

class AuthenticatedSessionController extends Controller
{
    private function getBidangRoute($id_bidang) {
        return match ($id_bidang) {
            1 => 'ppid',
            2 => 'keamanan',
            3 => 'assessment'
        };
    }

    public function store(LoginRequest $request): JsonResponse
    {
        try {
            $credentials = $request->only('email', 'password');

            // Try superadmin authentication
            $superadmin = Superadmin::where('email', $credentials['email'])->first();
            if ($superadmin && Hash::check($credentials['password'], $superadmin->password)) {
                Auth::guard('superadmin')->login($superadmin);
                $request->session()->regenerate();

                $bidangRoute = $this->getBidangRoute($superadmin->id_bidang);
                return response()->json([
                    'status' => 'success',
                    'user_type' => 'superadmin',
                    'user' => $superadmin,
                    'bidang' => $bidangRoute,
                    'redirect_url' => "/superadmin/{$bidangRoute}"
                ]);
            }

            // Try admin authentication
            $admin = Admin::where('email', $credentials['email'])->first();
            if ($admin && Hash::check($credentials['password'], $admin->password)) {
                Auth::guard('admin')->login($admin);
                $request->session()->regenerate();

                $bidangRoute = $this->getBidangRoute($admin->id_bidang);
                return response()->json([
                    'status' => 'success',
                    'user_type' => 'admin',
                    'user' => $admin,
                    'bidang' => $bidangRoute,
                    'redirect_url' => "/admin/{$bidangRoute}"
                ]);
            }

            return response()->json([
                'status' => 'error',
                'message' => 'Invalid credentials'
            ], 401);

        } catch (\Exception $e) {
            Log::error('Login error: ' . $e->getMessage(), [
                'exception' => $e,
                'trace' => $e->getTraceAsString(),
            ]);

            return response()->json([
                'status' => 'error',
                'message' => 'An error occurred during login.',
                'debug' => config('app.debug') ? $e->getMessage() : null
            ], 500);
        }
    }

    /**
     * Destroy an authenticated session.
     */
    public function destroy(Request $request): JsonResponse
    {
        // Logout logic for superadmin
        Auth::guard('superadmin')->logout();

        $request->session()->invalidate();

        $request->session()->regenerateToken();

        return response()->json([
            'status' => 'success',
            'message' => 'Session destroyed successfully.'
        ]);
    }
}
