<?php

namespace App\Models;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class Admin extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable;

    protected $primaryKey = 'id_admin';
    public $incrementing = true; // default true, tapi tetap bisa disebutkan eksplisit
    protected $keyType = 'int';

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'nip',
        'id_opd',
        'id_bidang',
        'password',
        'nama',
        'email',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
    ];

    // admin n opd 1:1
    public function opd()
    {
        return $this->belongsTo(Opd::class,'id_opd');
    }

    // admin n bidang layanan 1:1
    public function bidangLayanan()
    {
        return $this->belongsTo(BidangLayanan::class,'id_bidang');
    }

    // admin membuat laporan monev 1:N
    public function laporanMonev()
    {
        return $this->hasMany(LaporanMonev::class);
    }

    // admin memberikan tanggapan permohonan 1:N
    public function tanggapanPermohonan()
    {
        return $this->hasMany(TanggapanPermohonan::class);
    }
}
