import { createRouter, createWebHistory } from 'vue-router'
import LoginView from '@/views/LoginView.vue'
import PortalView from '@/views/portal/PortalView.vue'
import RegisterView from '@/views/RegisterView.vue'

// PPID Views
import PpidSuperadminView from '@/views/ppid/SuperadminView.vue'
import PpidAdminView from '@/views/ppid/AdminView.vue'
import PpidPermohonanView from '@/views/ppid/PermohonanView.vue'
import PpidKeberatanView from '@/views/ppid/KeberatanView.vue'
import PpidOpdView from '@/views/ppid/OpdView.vue'
import PpidLaporanView from '@/views/ppid/LaporanView.vue'

// Keamanan Views
import KeamananSuperadminView from '@/views/keamanan/SuperadminView.vue'
import KeamananAdminView from '@/views/keamanan/AdminView.vue'

// Assessment Views
import AssessmentSuperadminView from '@/views/assessment/SuperadminView.vue'
import AssessmentAdminView from '@/views/assessment/AdminView.vue'
import SettingsView from '@/views/ppid/SettingsView.vue'

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      name: 'home',
      component: PortalView,
    },
    {
      path: '/login',
      name: 'login',
      component: LoginView,
    },
    {
      path: '/register',
      name: 'register',
      component: RegisterView,
    },
    // PPID Routes
    {
      path: '/ppid/superadmin',
      name: 'superadmin-ppid',
      component: PpidSuperadminView,
    },
    {
      path: '/ppid/admin',
      name: 'admin-ppid',
      component: PpidAdminView,
      meta: { requiresAuth: true, role: 'admin' }
    },
    {
      path: '/ppid/superadmin/permohonan',
      name: 'ppid-permohonan',
      component: PpidPermohonanView,
    },
    {
      path: '/ppid/superadmin/keberatan',
      name: 'ppid-keberatan',
      component: PpidKeberatanView,
    },
    {
      path: '/ppid/superadmin/opd',
      name: 'ppid-opd',
      component: PpidOpdView,
    },
    {
      path: '/ppid/superadmin/laporan',
      name: 'ppid-laporan',
      component: PpidLaporanView,
    },
    {
      path: '/ppid/superadmin/settings',
      name: 'ppid-settings',
      component: SettingsView
    },
    // Keamanan Routes
    {
      path: '/keamanan/superadmin',
      name: 'superadmin-keamanan',
      component: KeamananSuperadminView,
      meta: { requiresAuth: true, role: 'superadmin' }
    },
    {
      path: '/keamanan/admin',
      name: 'admin-keamanan',
      component: KeamananAdminView,
      meta: { requiresAuth: true, role: 'admin' }
    },
    // Assessment Routes
    {
      path: '/assessment/superadmin',
      name: 'superadmin-assessment',
      component: AssessmentSuperadminView,
      meta: { requiresAuth: true, role: 'superadmin' }
    },
    {
      path: '/assessment/admin',
      name: 'admin-assessment',
      component: AssessmentAdminView,
      meta: { requiresAuth: true, role: 'admin' }
    }
  ],
})

// Add this helper function to get cookie value
function getCookie(name: string): string | null {
  const value = `; ${document.cookie}`
  const parts = value.split(`; ${name}=`)
  if (parts.length === 2) return parts.pop()?.split(';').shift() || null
  return null
}

// Update navigation guard to allow access without login
router.beforeEach((to, from, next) => {
  next()
})

export default router
